@@ -1,10 +1,11 @@
-from pyais.messages import NMEAMessage, ANY_MESSAGE
+from pyais.messages import NMEAMessage, ANY_MESSAGE, AISSentence
 from pyais.stream import TCPConnection, FileReaderStream, IterMessages
 from pyais.encode import encode_dict, encode_msg, ais_to_nmea_0183
 from pyais.decode import decode
+from pyais.tracker import AISTracker, AISTrack
 
 __license__ = 'MIT'
-__version__ = '2.4.0'
+__version__ = '2.5.0'
 __author__ = 'Leon Morten Richter'
 
 __all__ = (
@@ -12,9 +13,12 @@ __all__ = (
     'encode_msg',
     'ais_to_nmea_0183',
     'NMEAMessage',
+    'AISSentence',
     'ANY_MESSAGE',
     'TCPConnection',
     'IterMessages',
     'FileReaderStream',
     'decode',
+    'AISTracker',
+    'AISTrack',
 )
